import type { If, Is, And, Extends, GreaterThan, LengthOf } from "meta-types";
import { Type } from "../types.js";
import { ValueValidator } from "../value/validator.js";
import { CoreValidator, TreeTraverser } from "../core/validator.js";
import { AnyValidator } from "../any/validator.js";
import { ArrayOf, ArrayOfWithRest } from "../array-types.js";
import { TypeOf, Writeable } from "../functional.js";
export declare class TupleValidator<T extends any[], U extends CoreValidator<unknown>[], N extends number, // First optional index
A extends false | CoreValidator<unknown>> extends ValueValidator<T, TupleValidator<T, U, N, A>> {
    private validators;
    protected type: Type;
    private _unique;
    private _numRequired;
    private _minItems;
    private _maxItems;
    private _contains;
    private _additional;
    constructor(validators: ReadonlyArray<CoreValidator<any>>);
    const<V extends readonly T[number][]>(value: V): TupleValidator<Writeable<typeof value>, U, N, A>;
    enum<V extends readonly T[number][]>(...values: V[]): TupleValidator<Writeable<(typeof values)[number]>, U, N, A>;
    private static findMinItems;
    /**
     * ## Minimum number of items
     */
    minItems<N2 extends number>(min: N2): N2 extends N ? this : GreaterThan<N, N2> extends true ? never : And<Extends<A, false>, GreaterThan<N2, LengthOf<U>>> extends true ? never : TupleValidator<If<Is<A, false>, ArrayOf<U, N2>, ArrayOfWithRest<U, TypeOf<A>, N2>>, U, N2, A>;
    /**
     * ## Maximum number of items
     */
    maxItems(max: number): this;
    /**
     * ## Additional items
     *
     * `type` can be:
     *   * **`true`**: Any additional items
     *   * **`false`**: No additional items (default)
     *   * **a sub-validator**: Additional items are allowed of a certain type
     */
    additional<A extends boolean>(type: A): typeof type extends false ? this : TupleValidator<ArrayOfWithRest<U, any, N>, U, N, AnyValidator>;
    additional<B extends CoreValidator<unknown>>(type: B): TupleValidator<ArrayOfWithRest<U, TypeOf<B>, N>, U, N, B>;
    contains(validator: CoreValidator<any>): this;
    unique(unique?: boolean): this;
    protected toSchema(traverser: TreeTraverser): {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default?: undefined;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf?: undefined;
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf?: undefined;
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains: any;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems: number;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems: number;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    } | {
        uniqueItems?: boolean | undefined;
        maxItems?: undefined;
        minItems?: undefined;
        additionalItems: any;
        contains?: undefined;
        items: boolean | any[];
        allOf: Omit<any, "type">[];
        anyOf: Omit<any, "type">[];
        default: T;
        examples?: string[] | undefined;
        description?: string | undefined;
        title?: string | undefined;
        type: string;
    };
    protected clone(clean?: boolean): this;
}
